==> cms-db_v0.8.1.tar.gz: admin/locales/de/locale_includes.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['includes'] = array();

$locale['includes']['link_inclist'] = 'Liste';

$locale['includes']['title_inclist'] = 'Include-Liste';
$locale['includes']['desc_name'] = 'Name';
$locale['includes']['desc_no-includes'] = 'Keine Includes verfügbar!';
$locale['includes']['desc_moved-to-recyclebin'] = 'Der Include wurde erfolgreich in das Recycling-Center verschoben.';
$locale['includes']['desc_restored'] = 'Der Include wurde erfolgreich wiederhergestellt.';
$locale['includes']['desc_recyclebin'] = 'Mit einem Klick auf "löschen" werden Includes in das Recycling-Center verschoben.';

$locale['includes']['title_new'] = 'Neu';
$locale['includes']['desc_new'] = 'Bitte geben Sie einen Namen für den neuen Include ein:';
$locale['includes']['desc_new-error-copy'] = 'Der neue Include konnte nicht erstellt werden.';
$locale['includes']['desc_error-name'] = 'Ein Include mit dem gleichen Namen existiert bereits.';
$locale['includes']['desc_error-specialchars'] = 'Der Name des Includes enthält Sonderzeichen.';

$locale['includes']['title_rename'] = 'Include umbenennen';
$locale['includes']['desc_rename'] = 'Include <i>%s</i> umbenennen in:';
$locale['includes']['desc_rename-error'] = 'Der Include konnte nicht umbenannt werden.';
?>

==> cms-db_v0.9.tar.gz: admin/locales/de/locale_includes.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['includes'] = array();

$locale['includes']['desc_recyclebin'] = 'Mit einem Klick auf "löschen" werden Includes in das Recycling-Center verschoben.';
$locale['includes']['link_newinc'] = 'Include erstellen';
$locale['includes']['desc_no-includes'] = 'Keine Includes verfügbar!';
$locale['includes']['desc_moved-to-recyclebin'] = 'Der Include wurde erfolgreich in das Recycling-Center verschoben.';
$locale['includes']['desc_restored'] = 'Der Include wurde erfolgreich wiederhergestellt.';
$locale['includes']['title_newinc'] = 'Neuen Include erstellen';
$locale['includes']['desc_newinc'] = 'Geben Sie einen eindeutigen Namen ein, um einen Include zu erstellen.';
$locale['includes']['desc_new-error-copy'] = 'Der neue Include konnte nicht erstellt werden.';
$locale['includes']['desc_error-name'] = 'Ein Include mit dem gleichen Namen existiert bereits.';
$locale['includes']['desc_error-specialchars'] = 'Der Name des Includes enthält Sonderzeichen.';
$locale['includes']['title_rename'] = 'Include umbenennen';
$locale['includes']['desc_rename'] = 'Include <i>%s</i> umbenennen in:';
$locale['includes']['desc_rename-error'] = 'Der Include konnte nicht umbenannt werden.';
